# -*- coding: utf-8 -*-
# Generated by Django 1.9.6 on 2017-02-01 17:12
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Feedback',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('subject', models.CharField(max_length=255, verbose_name='Subject')),
                ('mobile', models.CharField(blank=True, max_length=255, null=True, verbose_name='Mobile')),
                ('email', models.EmailField(blank=True, max_length=255, null=True, verbose_name='Email')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date created')),
                ('text', models.TextField(max_length=1000, verbose_name='Message text')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='feedbacks', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Feedback message',
                'verbose_name_plural': 'Feedback messages',
            },
        ),
        migrations.CreateModel(
            name='ReturnCall',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('answer_time', models.PositiveIntegerField(choices=[(1, 'As fast as possible'), (2, 'In fixed time')], default=1, verbose_name='Answer time')),
                ('answer_start_time', models.TimeField(blank=True, default=b'08:00', null=True, verbose_name='Start time')),
                ('answer_end_time', models.TimeField(blank=True, default=b'08:30', null=True, verbose_name='End time')),
                ('mobile', models.CharField(max_length=21, verbose_name='Mobile')),
                ('date_created', models.DateTimeField(auto_now_add=True, verbose_name='Date created')),
                ('comment', models.TextField(blank=True, max_length=1000, verbose_name='Comment')),
                ('user', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='return_calls', to=settings.AUTH_USER_MODEL, verbose_name='User')),
            ],
            options={
                'verbose_name': 'Return call',
                'verbose_name_plural': 'Return calls',
            },
        ),
    ]
