
{% load i18n %}


<h1>{% trans 'New feedback message #' %} {{ feedback.id }}</h1> <br />

<strong>{% trans 'Subject' %}:</strong> <br />
{{ feedback.subject }} <br /><br />

<strong>{% trans 'Name' %}:</strong> <br />
{{ feedback.name }} <br /><br />

<strong>{% trans 'Email' %}:</strong> <br />
{{ feedback.email }} <br /><br />

<strong>{% trans 'Mobile' %}:</strong> <br />
{{ feedback.mobile }} <br /><br />

<strong>{% trans 'Message text' %}:</strong> <br />
{{ feedback.text }} <br /><br />

<a href="http://{{ site.domain }}{% url 'admin:contacts_feedback_change' feedback.id %}">{% trans 'Show on site' %}</a>
