
{% load i18n %}


<div class="modal fade" tabindex="-1" role="dialog">
    <div class="modal-dialog" role="document">
        <div class="modal-content">
            <div class="modal-header">
                <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                    <span aria-hidden="true">&times;</span>
                </button>
                <h4 class="modal-title">
                    {% trans 'Нове повідомлення' %}
                </h4>
            </div>
            <div class="modal-body">
                {% include 'contacts/feedback/form.html' %}
            </div>
            <div class="modal-footer">
                <button type="button" class="btn btn-success pull-left" data-role="submit-form-btn">
                    <i class="fa fa-envelope"></i>
                    {% trans 'Надіслати' %}
                </button>

                <button type="button" class="btn btn-default" data-dismiss="modal">
                    {% trans 'Відмінити' %}
                </button>
            </div>
        </div>
    </div>
</div>
