
{% load i18n widget_tweaks %}

<form method="post">

    {% csrf_token %}

    <div class="col-xs-12">
        <p>{% trans 'Якщо ви знайшли помилку на нашому сайті, ми будемо дуже вдячні, якщо ви коротко опишете її нижче' %}</p>
    </div>

    <div class="form-group m-b-10 {% if form.name.errors %}has-error{% endif %}">
        {{ form.name.label_tag }}
        {{ form.name|add_class:"form-control input-lg" }}
        {% if form.name.errors %}
            <span class="help-block">{{ form.name.errors }}</span>
        {% endif %}
    </div>

    <div class="form-group m-b-10 {% if form.email.errors %}has-error{% endif %}">
        {{ form.email.label_tag }}
        {{ form.email|add_class:"form-control input-lg" }}
        {% if form.email.errors %}
            <span class="help-block">{{ form.email.errors }}</span>
        {% endif %}
    </div>

    <div class="form-group m-b-10 {% if form.mobile.errors %}has-error{% endif %}">
        {{ form.mobile.label_tag }}
        {{ form.mobile|add_class:"form-control input-lg" }}
        {% if form.mobile.errors %}
            <span class="help-block">{{ form.mobile.errors }}</span>
        {% endif %}
    </div>

    <div class="form-group m-b-10 {% if form.text.errors %}has-error{% endif %}">
        {{ form.text.label_tag }}
        {{ form.text|add_class:'form-control'|attr:"rows:18" }}
        {% if form.text.errors %}
            <span class="help-block">{{ form.text.errors }}</span>
        {% endif %}
    </div>

    <div class="form-group">
        {{ form.captcha }}
        {% if form.captcha.errors %}
            <p class="text-danger">{{ form.captcha.errors.as_text }}</p>
        {% endif %}
    </div>

</form>

