
{% load i18n %}


<h1>{% trans 'New error message #' %} {{ error_message.id }}</h1> <br />

<strong>{% trans 'Name' %}:</strong> <br />
{{ error_message.name }} <br /><br />

<strong>{% trans 'Email' %}:</strong> <br />
{{ error_message.email }} <br /><br />

<strong>{% trans 'Mobile' %}:</strong> <br />
{{ error_message.mobile }} <br /><br />

<strong>{% trans 'Message text' %}:</strong> <br />
{{ error_message.text }} <br /><br />

<a href="http://{{ site.domain }}{% url 'admin:contacts_errormessage_change' error_message.id %}">
    {% trans 'Show on site' %}
</a>
